# -*- coding: utf-8 -*-
"""
     时间 : 2021-06-07 13:56
     作者 : 胡桓
     文件名 : myprint.py
     邮箱: 1641143982@qq.com
"""

import sys
import datetime

from testneo.log.settings import PRINT_COLOR, BG_COLOR

prefix_msg = '\033[1;{color}m{prefix}\033[0m'
detail_msg = '\033[1;{color}m{msg}\033[0m'
no_color_print = print


def color_print(self, *args, sep=' ', end='\n', file=None, color=PRINT_COLOR, bg_color=BG_COLOR):
    msg = repr(self) + sep + sep.join(repr(arg) for arg in args) + end
    line = sys._getframe().f_back.f_lineno
    file_name = sys._getframe(1).f_code.co_filename
    prefix = f'{datetime.datetime.now()} "{file_name}:{line}" '
    sys.stdout.write(prefix_msg.format(color=color, prefix=prefix))
    sys.stdout.write(detail_msg.format(color=bg_color, msg=msg))
    sys.stderr.flush()


def patch_print():
    try:
        __builtins__.print = color_print
    except AttributeError:
        __builtins__['print'] = color_print


def close_color_print():
    try:
        __builtins__.print = no_color_print
    except AttributeError:
        __builtins__['print'] = no_color_print


# -*- coding: utf-8 -*-
"""
     时间 : 2021-06-01 10:14
     作者 : 胡桓
     文件名 : settings.py
     邮箱: 1641143982@qq.com
"""

WHITE = 30  # 白色
RED = 31  # 红色
GREEN = 32  # 绿色
YELLOW = 33  # 黄色
BLUE = 34  # 蓝色
PURPLE = 35  # 紫色
BABYBLUE = 36  # 浅蓝色
GREY = 37  # 灰色
FrenchGREY = 38  # 浅灰色

PRINT_COLOR = RED
BG_COLOR = BLUE + 10

default_config = {
    'level': 'INFO',
    'name': 'root',
    'formatter': '[%(levelname)s - %(asctime)s - %(name)s - %(filename)s - line:%(lineno)d] %(message)s',
    'file': 'testneo.log',
    'error_color': RED,
    'warning_color': YELLOW,
    'info_color': WHITE,
    'debug_color': GREEN,
    'is_color_print':True,
}



# -*- coding: utf-8 -*-
"""
     时间 : 2021-05-28 16:27
     作者 : 胡桓
     文件名 : __init__.py.py
     邮箱: 1641143982@qq.com
"""

from __future__ import absolute_import

from testneo.log.myprint import no_color_print,color_print,patch_print,close_color_print
from testneo.log.settings import *

__all__ = ['no_color_print','color_print','patch_print']

if default_config.get('is_color_print'):
    patch_print()
else:
    close_color_print()


# -*- coding: utf-8 -*-
"""
     时间 : 2021-05-28 15:04
     作者 : 胡桓
     文件名 : setup.py
     邮箱: 1641143982@qq.com
"""
import setuptools

LICENSE = "MIT"
with open("README.md", "r",encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="testneo",
    version="0.1.3",
    author="胡桓",
    author_email='1641143982@qq.com',
    description='testneo自动化测试平台',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/neo19850910/testneo',
    packages=setuptools.find_packages(),
    license=LICENSE,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    zip_safe=True,
)
